@@ -11,15 +11,15 @@ _RELEASE = True
 
 
 if not _RELEASE:
-    _st_rating_component = components.declare_component("st_rating_component", url="http://localhost:3001" )
+    _st_rating_df = components.declare_component("st_rating_df", url="http://localhost:3001" )
 else:
     parent_dir = os.path.dirname(os.path.abspath(__file__))
     build_dir = os.path.join(parent_dir, "frontend/build")
-    _st_rating_component = components.declare_component("st_rating_component", path=build_dir)
+    _st_rating_df = components.declare_component("st_rating_df", path=build_dir)
 
 
 def st_rating_df(data,  height, width=-1, evaluationColumn=-1, key=None):
     if(evaluationColumn==-1):
         data.insert(loc=0, column='Rating', value=np.zeros(data.shape[0]))
         evaluationColumn=0
-    return _st_rating_component(data=data, evaluationColumn=evaluationColumn,width=width, height=height, key=key)
+    return _st_rating_df(data=data, evaluationColumn=evaluationColumn,width=width, height=height, key=key)
